@@ -15,6 +15,7 @@ HoltWintersZZ <- function(x,
                           warnings = TRUE # return optimization warnings
                         ) {
   x <- as.ts(x)
+  origx <- x
   seasonal <- match.arg(seasonal)
   m <- frequency(x)
   lenx <- length(x)
@@ -92,7 +93,8 @@ HoltWintersZZ <- function(x,
   ## initialise smoothing parameter
   optim.start <- initparam(
     alpha = alpha, beta = beta, gamma = gamma, phi = 1,
-    trendtype = trendtype, seasontype = seasontype, damped = FALSE, lower = lower, upper = upper, m = m
+    trendtype = trendtype, seasontype = seasontype, damped = FALSE, lower = lower, upper = upper, m = m,
+    bounds = "usual"
   )
 
   # if(!is.na(optim.start["alpha"]))
@@ -243,14 +245,15 @@ HoltWintersZZ <- function(x,
       fitted = fitted,
       residuals = res,
       components = components,
-      x = x,
+      x = origx,
       par = c(param, initstate),
       initstate = initstate,
       states = states,
       SSE = final.fit$SSE,
       sigma2 = sigma2,
       call = match.call(),
-      m = m
+      m = m,
+      lambda = lambda
     ),
     class = "ets"
   )
@@ -269,6 +272,13 @@ zzhw <- function(x, lenx, alpha=NULL, beta=NULL, gamma=NULL, seasonal="additive"
     phi <- 1
   }
 
+  if(abs(m - round(m)) > 1e-4) {
+    # Ignore seasonality
+    m <- 1
+  } else {
+    m <- round(m)
+  }
+
   # initialise array of l, b, s
   level <- trend <- season <- xfit <- residuals <- numeric(lenx)
   SSE <- 0
@@ -409,8 +419,8 @@ zzhw <- function(x, lenx, alpha=NULL, beta=NULL, gamma=NULL, seasonal="additive"
 #' it will be estimated.
 #' @param x Deprecated. Included for backwards compatibility.
 #' @param ... Other arguments passed to \code{forecast.ets}.
-#' @inheritParams forecast
-#' 
+#' @inheritParams forecast.ts
+#'
 #' @return An object of class "\code{forecast}".
 #'
 #' The function \code{summary} is used to obtain and print a summary of the
@@ -440,7 +450,7 @@ zzhw <- function(x, lenx, alpha=NULL, beta=NULL, gamma=NULL, seasonal="additive"
 #'
 #' @references Hyndman and Athanasopoulos (2018) \emph{Forecasting: principles
 #' and practice}, 2nd edition, OTexts: Melbourne, Australia.
-#' \url{https://OTexts.org/fpp2/}
+#' \url{https://otexts.com/fpp2/}
 #' @keywords ts
 #' @examples
 #'
